## Master Dark

The master dark frames are the product of the [`soxs_mdark`](../_api/soxspipe.recipes.soxs_mdark.html) recipe. The master-dark frame is to be subtracted from science/calibration frames to remove the contribution to pixel counts resulting from the dark-current.

